==> knative-model-4.12.0-sources.jar: io/fabric8/knative/serving/v1beta1/RouteBuilder.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RouteBuilder extends io.fabric8.knative.serving.v1beta1.RouteFluentImpl<io.fabric8.knative.serving.v1beta1.RouteBuilder> implements VisitableBuilder<io.fabric8.knative.serving.v1beta1.Route,io.fabric8.knative.serving.v1beta1.RouteBuilder> {

    io.fabric8.knative.serving.v1beta1.RouteFluent<?> fluent;
    Boolean validationEnabled;

    public RouteBuilder() { 
        this(true);
    }


    public RouteBuilder(Boolean validationEnabled) { 
        this(new Route(), validationEnabled);
    }


    public RouteBuilder(io.fabric8.knative.serving.v1beta1.RouteFluent<?> fluent) { 
        this(fluent, true);
    }


    public RouteBuilder(io.fabric8.knative.serving.v1beta1.RouteFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new Route(), validationEnabled);
    }


    public RouteBuilder(io.fabric8.knative.serving.v1beta1.RouteFluent<?> fluent,io.fabric8.knative.serving.v1beta1.Route instance) { 
        this(fluent, instance, true);
    }


    public RouteBuilder(io.fabric8.knative.serving.v1beta1.RouteFluent<?> fluent,io.fabric8.knative.serving.v1beta1.Route instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }


    public RouteBuilder(io.fabric8.knative.serving.v1beta1.Route instance) { 
        this(instance,true);
    }


    public RouteBuilder(io.fabric8.knative.serving.v1beta1.Route instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }


    public io.fabric8.knative.serving.v1beta1.Route build() {
        Route buildable = new Route(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        RouteBuilder that = (RouteBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.0.2-sources.jar: io/fabric8/knative/serving/v1beta1/RouteBuilder.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RouteBuilder extends io.fabric8.knative.serving.v1beta1.RouteFluentImpl<io.fabric8.knative.serving.v1beta1.RouteBuilder> implements VisitableBuilder<io.fabric8.knative.serving.v1beta1.Route,io.fabric8.knative.serving.v1beta1.RouteBuilder> {

    io.fabric8.knative.serving.v1beta1.RouteFluent<?> fluent;
    Boolean validationEnabled;

    public RouteBuilder() {
        this(true);
    }

    public RouteBuilder(Boolean validationEnabled) {
        this(new Route(), validationEnabled);
    }

    public RouteBuilder(io.fabric8.knative.serving.v1beta1.RouteFluent<?> fluent) {
        this(fluent, true);
    }

    public RouteBuilder(io.fabric8.knative.serving.v1beta1.RouteFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Route(), validationEnabled);
    }

    public RouteBuilder(io.fabric8.knative.serving.v1beta1.RouteFluent<?> fluent,io.fabric8.knative.serving.v1beta1.Route instance) {
        this(fluent, instance, true);
    }

    public RouteBuilder(io.fabric8.knative.serving.v1beta1.RouteFluent<?> fluent,io.fabric8.knative.serving.v1beta1.Route instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public RouteBuilder(io.fabric8.knative.serving.v1beta1.Route instance) {
        this(instance,true);
    }

    public RouteBuilder(io.fabric8.knative.serving.v1beta1.Route instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.serving.v1beta1.EditableRoute build() {
        EditableRoute buildable = new EditableRoute(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        RouteBuilder that = (RouteBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
